# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2020-05-19 00:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adyengo', '0021_auto_20180912_1526'),
    ]

    operations = [
        migrations.AlterField(
            model_name='recurringpaymentresult',
            name='psp_reference',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
    ]
