# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-05-27 22:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adyengo', '0009_auto_20160528_0015'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='payment_method',
            field=models.CharField(blank=True, choices=[('paypal', 'PayPal'), ('bankTransfer_DE', 'German Banktransfer'), ('card', 'All debit and credit cards'), ('visa', 'Visa'), ('bankTransfer', 'All banktransfers'), ('elv', 'ELV'), ('amex', 'Amex'), ('mc', 'Master Card'), ('directdebit_NL', 'Direct Debit (Netherlands)'), ('ideal', 'iDEAL'), ('directEbanking', 'SofortUberweisung'), ('bankTransfer_NL', 'Dutch Banktransfer')], max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='recurringpaymentresult',
            name='result_code',
            field=models.CharField(choices=[('Authorised', 'Authorised'), ('Refused', 'Refused'), ('Error', 'Error')], max_length=30),
        ),
        migrations.AlterField(
            model_name='session',
            name='country_code',
            field=models.CharField(blank=True, choices=[('DE', 'Germany'), ('NL', 'Netherlands'), ('BE', 'Belgium'), ('GB', 'United Kingdom')], max_length=2),
        ),
        migrations.AlterField(
            model_name='session',
            name='shopper_locale',
            field=models.CharField(blank=True, choices=[('fr_BE', 'French (Belgium)'), ('en_GB', 'English (United Kingdom)'), ('de_DE', 'German (Germany)'), ('nl_NL', 'Dutch (Holland)'), ('nl_BE', 'Dutch (Belgium)')], default='nl_NL', max_length=5),
        ),
        migrations.AlterField(
            model_name='sessionallowedpaymentmethods',
            name='method',
            field=models.CharField(choices=[('paypal', 'PayPal'), ('bankTransfer_DE', 'German Banktransfer'), ('card', 'All debit and credit cards'), ('visa', 'Visa'), ('bankTransfer', 'All banktransfers'), ('elv', 'ELV'), ('amex', 'Amex'), ('mc', 'Master Card'), ('directdebit_NL', 'Direct Debit (Netherlands)'), ('ideal', 'iDEAL'), ('directEbanking', 'SofortUberweisung'), ('bankTransfer_NL', 'Dutch Banktransfer')], max_length=50),
        ),
        migrations.AlterField(
            model_name='sessionblockedpaymentmethods',
            name='method',
            field=models.CharField(choices=[('paypal', 'PayPal'), ('bankTransfer_DE', 'German Banktransfer'), ('card', 'All debit and credit cards'), ('visa', 'Visa'), ('bankTransfer', 'All banktransfers'), ('elv', 'ELV'), ('amex', 'Amex'), ('mc', 'Master Card'), ('directdebit_NL', 'Direct Debit (Netherlands)'), ('ideal', 'iDEAL'), ('directEbanking', 'SofortUberweisung'), ('bankTransfer_NL', 'Dutch Banktransfer')], max_length=50),
        ),
    ]
