<!DOCTYPE html>
<html>

    <head>

        <title>Adyengo Testpages</title>

        <style>

            * {
                font-family: Arial;
                font-size: 16px;
            }

            table {
                margin-bottom: 10px;
            }

            table th,
            table td {
                vertical-align: top;
            }

            table th {
                text-align: left;
                padding-right: 20px;
                font-weight: normal;
            }

            h1 {
                font-size: 24px;
            }

            h2 {
                font-size: 18px;
            }

            ul {
                list-style: none;
                padding: 0;
            }

            input[type=text] {
                width: 500px;
            }

            .menu ul {
                display: flex;
            }

            .menu ul li {
                margin-right: 15px;
            }

        </style>

    </head>

    <body>

        <h1>Adyengo Testpages</h1>

        <nav class="menu">
            <ul>
                <li><a href="{% url 'adyengo:hpp_setup_session' %}">Normal session</a></li>
                <li><a href="{% url 'adyengo:api_setup_request_contracts' %}">Request recurring contracts</a></li>
                <li><a href="{% url 'adyengo:api_setup_disable_recurring_contract' %}">Disable recurring contract</a></li>
                <li><a href="{% url 'adyengo:api_setup_recurring_session' %}">Recurring payment session</a></li>
            </ul>
        </nav>

        {% block content %}{% endblock %}

    </body>
</html>
