# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-03 12:40
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adyengo', '0018_auto_20161013_1848'),
    ]

    operations = [
        migrations.AlterField(
            model_name='recurringpaymentresult',
            name='psp_reference',
            field=models.BigIntegerField(),
        ),
    ]
