# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-07-07 17:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adyengo', '0012_auto_20160610_1504'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='payment_method',
            field=models.CharField(blank=True, choices=[('directdebit_NL', 'Direct Debit (Netherlands)'), ('amex', 'Amex'), ('elv', 'ELV'), ('ideal', 'iDEAL'), ('card', 'All debit and credit cards'), ('bankTransfer_DE', 'German Banktransfer'), ('directEbanking', 'SofortUberweisung'), ('paypal', 'PayPal'), ('mc', 'Master Card'), ('visa', 'Visa'), ('bankTransfer', 'All banktransfers'), ('bankTransfer_NL', 'Dutch Banktransfer')], max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='recurringpaymentresult',
            name='result_code',
            field=models.CharField(choices=[('Received', 'Received'), ('Refused', 'Refused'), ('Error', 'Error'), ('Authorised', 'Authorised')], max_length=30),
        ),
        migrations.AlterField(
            model_name='session',
            name='country_code',
            field=models.CharField(choices=[('BE', 'Belgium'), ('DE', 'Germany'), ('GB', 'United Kingdom'), ('NL', 'Netherlands')], max_length=2),
        ),
        migrations.AlterField(
            model_name='session',
            name='page_type',
            field=models.CharField(choices=[('single', 'Single'), ('skip', 'Skip'), ('multiple', 'Multiple')], default='multiple', max_length=15),
        ),
        migrations.AlterField(
            model_name='session',
            name='session_type',
            field=models.CharField(choices=[('hpp_regular', 'HPP Regular'), ('api_recurring', 'API Recurring'), ('hpp_recurring', 'HPP Recurring')], max_length=25),
        ),
        migrations.AlterField(
            model_name='session',
            name='shopper_locale',
            field=models.CharField(blank=True, choices=[('fr_BE', 'French (Belgium)'), ('de_DE', 'German (Germany)'), ('en_GB', 'English (United Kingdom)'), ('nl_BE', 'Dutch (Belgium)'), ('nl_NL', 'Dutch (Holland)')], default='nl_NL', max_length=5),
        ),
        migrations.AlterField(
            model_name='sessionallowedpaymentmethods',
            name='method',
            field=models.CharField(choices=[('directdebit_NL', 'Direct Debit (Netherlands)'), ('amex', 'Amex'), ('elv', 'ELV'), ('ideal', 'iDEAL'), ('card', 'All debit and credit cards'), ('bankTransfer_DE', 'German Banktransfer'), ('directEbanking', 'SofortUberweisung'), ('paypal', 'PayPal'), ('mc', 'Master Card'), ('visa', 'Visa'), ('bankTransfer', 'All banktransfers'), ('bankTransfer_NL', 'Dutch Banktransfer')], max_length=50),
        ),
        migrations.AlterField(
            model_name='sessionblockedpaymentmethods',
            name='method',
            field=models.CharField(choices=[('directdebit_NL', 'Direct Debit (Netherlands)'), ('amex', 'Amex'), ('elv', 'ELV'), ('ideal', 'iDEAL'), ('card', 'All debit and credit cards'), ('bankTransfer_DE', 'German Banktransfer'), ('directEbanking', 'SofortUberweisung'), ('paypal', 'PayPal'), ('mc', 'Master Card'), ('visa', 'Visa'), ('bankTransfer', 'All banktransfers'), ('bankTransfer_NL', 'Dutch Banktransfer')], max_length=50),
        ),
    ]
